<img src='https://img.shields.io/pypi/l/blank.svg'> <img src='https://img.shields.io/pypi/pyversions/blank.svg'> <img src='https://img.shields.io/pypi/v/blank.svg'> <img src='https://img.shields.io/pypi/dm/blank.svg'> <img src='https://img.shields.io/badge/code%20style-black-000000.svg'>

# python-blank
A blank / template for creating a new Python package

# Installation

```
$ pip install blank
```

# Usage

## CLI

```
$ hello_blank
Welcome to Blank package!
```

## Package

``` python
import blank

print(blank.reverse("minhng.info")) # "ofni.gnhnim"
```
